@@ -50,14 +50,18 @@ xmlNodePtr
 domReplaceChild( xmlNodePtr self,
                  xmlNodePtr oldChlid,
                  xmlNodePtr newChild );
-/* xmlNodePtr */
-/* domInsertBefore( xmlNodePtr self,  */
-/* 		 xmlNodePtr newChild, */
-/* 		 xmlNodePtr refChild ); */
 xmlNodePtr
-domRemoveNode( xmlNodePtr self,
+domRemoveChild( xmlNodePtr self,
                xmlNodePtr Child );
+xmlNodePtr
+domInsertBefore( xmlNodePtr self, 
+                 xmlNodePtr newChild,
+                 xmlNodePtr refChild );
 
+xmlNodePtr
+domInsertAfter( xmlNodePtr self, 
+                xmlNodePtr newChild,
+                xmlNodePtr refChild );
 
 /* A.3 extra functionality not specified in DOM L1/2*/
 void
@@ -71,6 +75,9 @@ domUnbindNode(  xmlNodePtr self );
 const char*
 domNodeTypeName( xmlNodePtr self );
 
+xmlNodePtr
+domIsNotParentOf( xmlNodePtr testNode, xmlNodePtr refNode );
+
 /** 
  * part B:
  *
@@ -85,6 +92,8 @@ domDocumentElement( xmlDocPtr document );
 xmlNodePtr
 domSetDocumentElement( xmlDocPtr document, 
 		       xmlNodePtr newRoot);
+xmlNodePtr
+domImportNode( xmlDocPtr document, xmlNodePtr node, int move );
 
 /**
  * part C:
@@ -95,4 +104,7 @@ domSetDocumentElement( xmlDocPtr document,
 xmlNodeSetPtr
 domGetElementsByTagName( xmlNodePtr self, xmlChar* name );
 
+xmlNodePtr
+domSetOwnerDocument( xmlNodePtr self, xmlDocPtr doc );
+
 #endif
